==> corpengine1-1.2.dev5.tar.gz: corpengine1-1.2.dev5/README.md <==
![Banner](https://imagizer.imageshack.com/img922/2867/oKxyGS.png)
[![GitHub license](https://img.shields.io/github/license/PyxleDev0/corp-engine)](https://github.com/PyxleDev0/corp-engine/blob/master/LICENSE)
![Version](https://img.shields.io/badge/Version-v1.2-informational)

# CORP Engine

## What is CORP Engine?
CORP Engine is a game engine/toolkit made in Python using the Pygame library.

### Why should I use it?
- It can really make your python game development experience more organized, faster, and better in general.
- It has **built-in parent-children system** with **game objects** and **services** to use. 
- It is very simple and efficient to work with compared to Pygame.

### How can I set it up?
* Download the package using pip:

   `pip install corpengine1`

* Or you could use this repository as a template if you want to contribute to the engine.

![image](https://user-images.githubusercontent.com/75680333/151244534-53a48093-6251-4a3a-a582-bb32df089257.png)


## Learning CORP Engine
There is no wiki for now but [here](https://github.com/corpengine/examples/) are some examples and the source code also includes typehints and comments!

## Contributing
If you are a random adventurer looking through the source code and have an idea or found a problem, feel free to open an [issue](https://github.com/corpengine/corpengine/issues) or a [pull request](https://github.com/corpengine/corpengine/pulls). 

Even a small contribution means a lot!

### Contributors

![GitHub Contributors Image](https://contrib.rocks/image?repo=PyxleDev0/corp-engine)

==> corpengine1-1.3.dev10.tar.gz: corpengine1-1.3.dev10/README.md <==
![Banner](https://imagizer.imageshack.com/img922/2867/oKxyGS.png)
[![GitHub license](https://img.shields.io/github/license/PyxleDev0/corp-engine)](https://github.com/PyxleDev0/corp-engine/blob/master/LICENSE)
![Version](https://img.shields.io/badge/Version-v1.3-informational)

# CORP Engine

## What is CORP Engine?
CORP Engine is a game engine/toolkit made in Python using the Pygame library.

### Why should I use it?
- It can really make your python game development experience more organized, faster, and better in general.
- It has **built-in parent-children system** with **game objects** and **services** to use. 
- It is very simple and efficient to work with compared to Pygame.

### How can I set it up?
#### Recommended
* Download the package using pip: `pip install corpengine1`
#### Other
* Use this repository as a template or fork it
* Download as zip / download raw files or open with GitHub Desktop (The main file is "*/corpengine1/\__init\__.py*")
* `git copy` it to your local machine

![image](https://user-images.githubusercontent.com/75680333/151244534-53a48093-6251-4a3a-a582-bb32df089257.png) 

*Using repository as a template*



## Learning CORP Engine
There is no wiki for now but [here](https://github.com/corpengine/examples/) are some examples and the source code also includes typehints and comments!

## Contributing
If you are a random adventurer looking through the source code and have an idea or found a problem, feel free to open an [issue](https://github.com/corpengine/corpengine/issues) or a [pull request](https://github.com/corpengine/corpengine/pulls). 

Also, you can **star the repository**! You don't need more than a few seconds to do it, and it will help development :)

Even a small contribution means a lot!

### Contributors

![GitHub Contributors Image](https://contrib.rocks/image?repo=PyxleDev0/corp-engine)
